==> bacula-docs-2.4.2.tar.bz2: bacula-docs-2.4.2/home-page/de/pages/license.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr> no longer needed, the link on the website points to the dev-manual
        <td class="contentTopic">
                Bacula Urheberrecht, Handelsmarke und Lizenz
        </td>
</tr>
<tr>
  <td class="content">
	Bacula verwendet eine Reihe unterschiedlicher Lizenzen.
     <h3>GPL</h3>
	Der wesentliche Teil des Quelltextes ist unter der 
     <a href="rel-manual/gpl.html">GNU General Public License version 2.</a>
	ver&ouml;ffentlicht.
     Most of this code is copyrighted:
     Copyright (C) 2000-2007 Free Software Foundation Europe, e.V.
     <p>Portions may be copyrighted by other people (ATT, the
     Free Software Foundation, ...).
     <h3>LGPL</h3>
     Some of the Bacula library source code is released under the
     <a href="rel-manual/lesser.html">GNU Lesser General Public License.</a>
     This permits third parties to use these parts of our code in
     their proprietary programs to interface to Bacula.
     <h3>Public Domain</h3>
     Some of the Bacula code has been released to the public domain.
     E.g. md5.c, SQLite.
     <h3>Trademark</h3>
     Bacula<sup>&reg;</sup>is a registered trademark of John
     Walker.

     <p>We have done this to ensure that any variant of Bacula will
     be exactly compatible with the program that we have released.
     The use of the name <b>Bacula</b> is restricted to software systems
     that agree exactly with the program presented here.
     </p>
  </td>
</tr>
</table>

<? require_once("inc/footer.php"); ?>

==> bacula-docs-5.0.2.tar.bz2: bacula-docs-5.0.2/home-page/de/pages/license.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr> no longer needed, the link on the website points to the dev-manual
        <td class="contentTopic">
                Bacula Urheberrecht, Handelsmarke und Lizenz
        </td>
</tr>
<tr>
  <td class="content">
        Bacula verwendet eine Reihe unterschiedlicher Lizenzen.
     <h3>GPL</h3>
        Der wesentliche Teil des Quelltextes ist unter der 
     <a href="rel-manual/gpl.html">GNU General Public License version 2.</a>
        ver&ouml;ffentlicht.
     Most of this code is copyrighted:
     Copyright (C) 2000-2009 Free Software Foundation Europe, e.V.
     <p>Portions may be copyrighted by other people (ATT, the
     Free Software Foundation, ...).
     <h3>LGPL</h3>
     Some of the Bacula library source code is released under the
     <a href="rel-manual/lesser.html">GNU Lesser General Public License.</a>
     This permits third parties to use these parts of our code in
     their proprietary programs to interface to Bacula.
     <h3>Public Domain</h3>
     Some of the Bacula code has been released to the public domain.
     E.g. md5.c, SQLite.
     <h3>Trademark</h3>
     Bacula<sup>&reg;</sup>is a registered trademark of Kern Sibbald.

     <p>We have done this to ensure that any variant of Bacula will
     be exactly compatible with the program that we have released.
     The use of the name <b>Bacula</b> is restricted to software systems
     that agree exactly with the program presented here.
     </p>
  </td>
</tr>
</table>

<? require_once("inc/footer.php"); ?>
